package com.diagbot.client;

import java.util.List;
import java.util.Map;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import com.diagbot.client.bean.HosCodeVO;
import com.diagbot.client.hystrix.TranServiceHystrix;
import com.diagbot.dto.GetDiseaseIcdDTO;
import com.diagbot.dto.GetTopPatientInfoDTO;
import com.diagbot.dto.HospitalDeptInfoDTO;
import com.diagbot.vo.HospitalDeptInfoVO;
import com.diagbot.dto.IndexDataDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.vo.GetDiseaseIcdVO;
import com.diagbot.vo.GetTopPatientInfoVO;
import com.diagbot.vo.IndexDataSaveVO;
import com.diagbot.vo.IndexDataiIds;

/**
 * @Description: 调用信息对接层服务
 * @author: gaodm
 * @time: 2019/2/1 17:00
 */
@FeignClient(value = "tran-service", fallback = TranServiceHystrix.class)
public interface TranServiceClient {
    /**
     * 获取科室信息
     *
     * @param hospitalDeptInfoVO
     * @return
     */
    @PostMapping("/hospitalDeptInfo/getHospitalDeptInfo")
    RespDTO<HospitalDeptInfoDTO> getHospitalDeptInfo(@RequestBody HospitalDeptInfoVO hospitalDeptInfoVO);

    /**
     * 根据医院编号疾病概念名称获取各医院对应的诊断icd
     *
     * @param getDiseaseIcdVO
     * @return
     */
    @PostMapping("/diseaseIcd/getDiseaseIcds")
    RespDTO<List<GetDiseaseIcdDTO>> getDiseaseIcds(@RequestBody GetDiseaseIcdVO getDiseaseIcdVO);
    
    /**
     * 获取页面顶部病人医生科室信息
     *
     * @param getTopPatientInfoVO
     * @return
     */
    @PostMapping("/patientInfo/getTopPatientInfo")
    RespDTO<GetTopPatientInfoDTO> getTopPatientInfo(@RequestBody GetTopPatientInfoVO getTopPatientInfoVO);

    /**
     * 根据医院编码获取化验公表映射关系-itemName不为空
     *
     * @param hosCodeVO
     * @return
     */
    @PostMapping("/tranLisConfig/getLisConfigByHosCode_NotEmptyItemName")
    RespDTO<Map<String, Map<String, String>>> getLisConfigByHosCode_NotEmptyItemName(@RequestBody HosCodeVO hosCodeVO);

    /**
     * 根据医院编码获取化验公表映射关系-itemName为空
     *
     * @param hosCodeVO
     * @return
     */
    @PostMapping("/tranLisConfig/getLisConfigByHosCode_EmptyItemName")
    RespDTO<Map<String, String>> getLisConfigByHosCode_EmptyItemName(@RequestBody HosCodeVO hosCodeVO);

    /**
     * 根据医院编码获取辅检公表映射关系
     *
     * @param hosCodeVO
     * @return
     */
    @PostMapping("/pacsConfig/getPacsConfigByHosCode")
    RespDTO<Map<String, String>> getPacsConfigByHosCode(@RequestBody HosCodeVO hosCodeVO);

    /**
     * 根据医院编码获取提示信息标题映射关系
     *
     * @param hosCodeVO
     * @return
     */
    @PostMapping("/introduceTitleConfig/getTitleMappingHosCode")
    RespDTO<Map<String, String>> getTitleMappingHosCode(@RequestBody HosCodeVO hosCodeVO);

    /**
     * 根据医院编码查询诊断icd映射
     *
     * @param hosCodeVO
     * @return
     */
    @PostMapping("/diseaseIcd/getDiseaseIcdByHosCode")
    RespDTO<Map<String, String>> getDiseaseIcdByHosCode(@RequestBody HosCodeVO hosCodeVO);

    /**
     * 数据服务模式是否对外对接
     *
     * @return
     */
    @PostMapping("/dataService/isDocking")
    RespDTO<Boolean> isDocking();

    /**
     * 根据医院编码获取化验公表映射关系，公表项做key
     *
     * @param hosCodeVO
     * @return
     */
    @PostMapping("/tranLisConfig/getLisConfigByUniqueNameAndHosCode")
    RespDTO<Map<String, List<String>>> getLisConfigByUniqueNameAndHosCode(@RequestBody HosCodeVO hosCodeVO);

    /**
     * 根据医院编码查询辅检公表映射，公表项做key
     *
     * @param hosCodeVO
     * @return
     */
    @PostMapping("/pacsConfig/getPacsConfigByUniqueNameAndHosCode")
    RespDTO<Map<String, List<String>>> getPacsConfigByUniqueNameAndHosCode(@RequestBody HosCodeVO hosCodeVO);

	/**
	 * 指标数据获取
	 * @param indexDataFindVO
	 * @return
	 */
	@PostMapping(value = "/indexData/getIndexDatas")
	RespDTO<List<IndexDataDTO>> getIndexDatas(@RequestBody IndexDataiIds indexDataFindVO);

	/**
	 * 指标数据保存
	 * @param indexDataSaveVO
	 * @return
	 */
	@PostMapping(value = "/indexData/saveIndexDatas")
	RespDTO<Boolean> saveIndexDatas(@RequestBody IndexDataSaveVO indexDataSaveVO);
}