package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.diagbot.client.AiptServiceClient;
import com.diagbot.client.bean.ConceptBaseVO;
import com.diagbot.client.bean.DisTypeVO;
import com.diagbot.client.bean.Medicition;
import com.diagbot.dto.RespDTO;
import com.diagbot.entity.InquiryDrug;
import com.diagbot.entity.InquiryInfo;
import com.diagbot.enums.DisTypeEnum;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.util.RespDTOUtil;
import com.google.common.collect.Lists;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:zhaops
 * @time: 2018/12/17 13:41
 */
@Component
public class TreatmentFacade {
    @Autowired
    QuestionFacade questionFacade;
    @Autowired
    InquiryInfoFacade inquiryInfoFacade;
    @Autowired
    InquiryDrugFacade inquiryDrugFacade;
    @Autowired
    AiptServiceClient aiptServiceClient;

    /**
     * 获取治疗方案
     *
     * @param
     * @return
     */
    public Map<String, Object> getTreatment(Map<String, Object> map, Long patientId) {
        Map<String, Object> retMap = map;
        //慢病 上次用药处理
        if (map.containsKey("drugHistory")) {
            //上次用药
            if (patientId == null) {
                retMap.put("drugHistory", null);
            } else {
                retMap.put("drugHistory", getDrugHistory(patientId));
            }
        }
        return retMap;
    }


    /**
     * 根据病人id获取历史用药内容
     *
     * @param patientId
     * @return
     */
    public Map<String, List<Medicition>> getDrugHistory(Long patientId) {
        Map<String, List<Medicition>> drugHistoryMap = new LinkedHashMap<>();
        QueryWrapper<InquiryInfo> inquiryInfoQueryWrapper = new QueryWrapper<>();
        inquiryInfoQueryWrapper.eq("is_deleted", IsDeleteEnum.N.getKey()).
                eq("patient_id", patientId).
                orderByDesc("gmt_modified");
        List<InquiryInfo> inquiryInfoList = inquiryInfoFacade.list(inquiryInfoQueryWrapper);
        Boolean chronicHistroy = false;
        Boolean not_chronicHistory = false;
        for (InquiryInfo inquiryInfo : inquiryInfoList) {
            //慢病和普通病都取到上次用药之后不再遍历
            if (chronicHistroy && not_chronicHistory) {
                break;
            }
            String[] diseases = inquiryInfo.getDiagnose().split(",|，");
            if (diseases.length > 0) {
                QueryWrapper<InquiryDrug> inquiryDrugQueryWrapper = new QueryWrapper<>();
                inquiryDrugQueryWrapper.eq("is_deleted", IsDeleteEnum.N.getKey()).eq("inquiry_id", inquiryInfo.getId());
                List<InquiryDrug> inquiryDrugList = inquiryDrugFacade.list(inquiryDrugQueryWrapper);
                List<Medicition> medicitionList = Lists.newLinkedList();
                for (InquiryDrug inquiryDrug : inquiryDrugList) {
                    Medicition medicition = new Medicition();
                    medicition.setConceptId(inquiryDrug.getConceptId());
                    medicition.setMedicitionName(inquiryDrug.getConceptName());
                    medicition.setLibType(8);
                    medicition.setIsShow("1");
                    ConceptBaseVO conceptBaseVO = new ConceptBaseVO();
                    conceptBaseVO.setName(medicition.getMedicitionName());
                    conceptBaseVO.setLibType(8);
                    RespDTO<Boolean> res = aiptServiceClient.existConceptDetail(conceptBaseVO);
                    if (RespDTOUtil.respIsOK(res) && res.data == true) {
                        medicition.setShowInfo("1");
                    } else {
                        medicition.setShowInfo("0");
                    }
                    medicitionList.add(medicition);
                }

                DisTypeVO disTypeVO = new DisTypeVO();
                disTypeVO.setName(diseases[0]);
                disTypeVO.setDisType(DisTypeEnum.CHRONIC.getKey());
                RespDTO<Boolean> resDisType = aiptServiceClient.verifyDisType(disTypeVO);
                if (RespDTOUtil.respIsOK(resDisType) && resDisType.data == true) {
                    if (!chronicHistroy) {
                        drugHistoryMap.put("慢病用药内容", medicitionList);
                        chronicHistroy = true;
                    } else {
                        if (!not_chronicHistory) {
                            drugHistoryMap.put("普通病用药内容", medicitionList);
                            not_chronicHistory = true;
                        }
                    }
                }
            }
        }
        return drugHistoryMap;
    }
}